# orderly-sdk-py

Orderly.network Python SDk

**Note: Only async Rest and Websocket APIs are maintained.**

## API docs

* NEAR API(v1): <https://docs-api.orderly.network/>
* EVM API(v2): <https://docs-api-evm.orderly.network/>
